@@ -158,6 +158,7 @@
 {"bessel_Inu",gsl_sf_bessel_Inu_wrap,METH_VARARGS},
 {"bessel_Knu_scaled_e",gsl_sf_bessel_Knu_scaled_e_wrap,METH_VARARGS},
 {"bessel_Knu_scaled",gsl_sf_bessel_Knu_scaled_wrap,METH_VARARGS},
+{"bessel_Knu_scaled_e10_e",gsl_sf_bessel_Knu_scaled_e10_e_wrap,METH_VARARGS},
 {"bessel_Knu_e",gsl_sf_bessel_Knu_e_wrap,METH_VARARGS},
 {"bessel_Knu",gsl_sf_bessel_Knu_wrap,METH_VARARGS},
 {"bessel_lnKnu_e",gsl_sf_bessel_lnKnu_e_wrap,METH_VARARGS},
@@ -437,12 +438,18 @@
 {"log_1plusx",gsl_sf_log_1plusx_wrap,METH_VARARGS},
 {"log_1plusx_mx_e",gsl_sf_log_1plusx_mx_e_wrap,METH_VARARGS},
 {"log_1plusx_mx",gsl_sf_log_1plusx_mx_wrap,METH_VARARGS},
+{"mathieu_a_e",gsl_sf_mathieu_a_e_wrap,METH_VARARGS},
 {"mathieu_a",gsl_sf_mathieu_a_wrap,METH_VARARGS},
+{"mathieu_b_e",gsl_sf_mathieu_b_e_wrap,METH_VARARGS},
 {"mathieu_b",gsl_sf_mathieu_b_wrap,METH_VARARGS},
 {"mathieu_a_coeff",gsl_sf_mathieu_a_coeff_wrap,METH_VARARGS},
 {"mathieu_b_coeff",gsl_sf_mathieu_b_coeff_wrap,METH_VARARGS},
+{"mathieu_ce",gsl_sf_mathieu_ce_wrap,METH_VARARGS},
+{"mathieu_se_e",gsl_sf_mathieu_se_e_wrap,METH_VARARGS},
 {"mathieu_se",gsl_sf_mathieu_se_wrap,METH_VARARGS},
+{"mathieu_Mc_e",gsl_sf_mathieu_Mc_e_wrap,METH_VARARGS},
 {"mathieu_Mc",gsl_sf_mathieu_Mc_wrap,METH_VARARGS},
+{"mathieu_Ms_e",gsl_sf_mathieu_Ms_e_wrap,METH_VARARGS},
 {"mathieu_Ms",gsl_sf_mathieu_Ms_wrap,METH_VARARGS},
 {"pow_int_e",gsl_sf_pow_int_e_wrap,METH_VARARGS},
 {"pow_int",gsl_sf_pow_int_wrap,METH_VARARGS},
