@@ -1,17 +1,13 @@
 # Author : Fabian Jakobs
-# $Id: $
 import unittest
 import pygsl
 from pygsl.linalg import *
 from gsl_test import *
 import pygsl._numobj as numx
 
-#pygsl.set_debug_level(10)
-class LinalgTestCase(GSLTestCase):        
+class LinalgTestCase(GSLTestCase):
     def testLU_decomp(self):
-        #pygsl.set_debug_level(3)
         (lu, p, s) = LU_decomp(self.m1_4)
-        pygsl.set_debug_level(0)
         (l,u) = LU_unpack(lu)
         dot = numx.dot(l,u)
         result = zeros((4,4), Float)
@@ -24,7 +20,6 @@ class LinalgTestCase(GSLTestCase):
         self.assertTrue(res)
 
     def testLU_solve(self):
-
         A = array([[1,2], [1,3]], Float)
         b = array([3,4], Float)
         (lu, p, s) = LU_decomp(A)
@@ -32,7 +27,6 @@ class LinalgTestCase(GSLTestCase):
         self.assertTrue(x[0] == 1 and x[1] == 1)
 
     def testLU_solve_complex(self):
-        
         A = array([[1,2], [1,3]], Complex)
         b = array([3,4], Complex)
         (lu, p, s) = LU_decomp(A)
@@ -40,7 +34,6 @@ class LinalgTestCase(GSLTestCase):
         self.assertTrue(x[0] == 1 and x[1] == 1)
 
     def testLU_invert(self):
-        
         (lu, p, s) = LU_decomp(self.m1_4)
         invert = LU_invert(lu,p)
         result = reshape(dot(self.m1_4, invert)-identity(4), (-1,))
@@ -50,21 +43,18 @@ class LinalgTestCase(GSLTestCase):
         self.assertTrue(res)
 
     def testLU_det(self):
-        
         (lu, p, s) = LU_decomp(self.m1_4)
         det = LU_det(lu,s)
         result = fpcompare(det, 15.744, 3)
         self.assertTrue(result)
 
     def testLU_lndet(self):
-        
         (lu, p, s) = LU_decomp(self.m1_4)
         lndet = LU_lndet(lu)
         result = fpcompare(lndet, numx.log(15.744), 3)
         self.assertTrue(result)
         
     def testLU_sgndet(self):
-        
         (lu, p, s) = LU_decomp(self.m1_4)
         det = LU_sgndet(lu,s)
         self.assertTrue(det == 1)
@@ -263,7 +253,7 @@ class LinalgTestCase(GSLTestCase):
         self.assertTrue(result)
 
 if __name__ == '__main__':
-    unittest.main(verbosity=1)
+    unittest.main()
 
 
 
